Summarizes how effectiveness estimates were obtained including analysis method, key parameters, and descriptives to aid in understanding the analysis.
Usage
# S3 method for class 'nomatchfit'
summary(object, digits = 4, show_models = FALSE, ...)Arguments
- object
An object of class
nomatchfitcreated bynomatch()ormatching().- digits
Integer indicating the number of decimal places to display. Default is 4.
- show_models
Logical; print model details? Default is FALSE.
- ...
Additional arguments (currently ignored).